bayespy.inference.vmp.nodes.categorical_markov_chain.CategoricalMarkovChainMoments.get_converter
================================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical_markov_chain

.. automethod:: CategoricalMarkovChainMoments.get_converter